@@ -15,8 +15,8 @@ use AI::MXNet::Function::Parameters;
     attrs : hash ref of str to str
         attributes of this variable taken from AI::MXNet::Symbol->attr_dict
 =cut
-has 'name'   => (is => 'ro', isa => 'Str', required => 1);
-has 'attrs'  => (is => 'rw', isa => 'HashRef[Str]', lazy => 1, default => sub { +{} });
+has 'name'        => (is => 'ro', isa => 'Str', required => 1);
+has 'attrs'       => (is => 'rw', isa => 'HashRef[Str]', lazy => 1, default => sub { +{} });
 use overload '""' => sub { shift->name };
 around BUILDARGS => sub {
     my $orig  = shift;
@@ -42,6 +42,15 @@ use overload "&{}" => sub { my $self = shift; sub { $self->call(@_) } },
              },
              fallback => 1;
 has 'kwargs' => (is => 'rw', init_arg => undef, isa => 'HashRef');
+has '_verbose'    => (is => 'rw', isa => 'Bool', lazy => 1, default => 0);
+has '_print_func' => (is => 'rw', isa => 'CodeRef', lazy => 1,
+    default => sub {
+        return sub {
+            my $x = shift;
+            return ($x->norm/sqrt($x->size))->asscalar;
+        };
+    }
+);
 
 =head1 NAME
 
@@ -52,6 +61,34 @@ has 'kwargs' => (is => 'rw', init_arg => undef, isa => 'HashRef');
     Register an initializer class to the AI::MXNet::Initializer factory.
 =cut
 
+=head2 set_verbosity
+
+    Switch on/off verbose mode
+
+    Parameters
+    ----------
+    $verbose : bool
+        switch on/off verbose mode
+    $print_func : CodeRef
+        A function that computes statistics of initialized arrays.
+        Takes an AI::MXNet::NDArray and returns a scalar. Defaults to mean
+        absolute value |x|/size(x)
+=cut
+
+method set_verbosity(Bool $verbose=0, CodeRef $print_func=)
+{
+    $self->_verbose($verbose);
+    $self->_print_func($print_func) if defined $print_func;
+}
+
+method _verbose_print($desc, $init, $arr)
+{
+    if($self->_verbose and defined $self->_print_func)
+    {
+        AI::MXNet::Logging->info('Initialized %s as %s: %s', $desc, $init, $self->_print_func->($arr));
+    }
+}
+
 my %init_registry;
 method get_init_registry()
 {
@@ -99,6 +136,7 @@ method call(Str|AI::MXNet::InitDesc $desc, AI::MXNet::NDArray $arr)
     {
       my ($klass, $kwargs) = @{ decode_json($init) };
       $self->get_init_registry->{ lc $klass }->new(%{ $kwargs })->_init_weight("$desc", $arr);
+      $self->_verbose_print($desc, $init, $arr);
     }
     else
     {
@@ -107,6 +145,7 @@ method call(Str|AI::MXNet::InitDesc $desc, AI::MXNet::NDArray $arr)
         {
             my $method = "_init_$1";
             $self->$method($desc, $arr);
+            $self->_verbose_print($desc, $1, $arr);
         }
         else
         {
