@@ -18,6 +18,7 @@ package AI::MXNet::Module;
 use AI::MXNet::Base;
 use AI::MXNet::Function::Parameters;
 use List::Util qw(max);
+use Data::Dumper ();
 use Mouse;
 
 func _create_kvstore(
@@ -71,10 +72,11 @@ func _initialize_kvstore(
 {
     enumerate(sub{
         my ($idx, $param_on_devs) = @_;
-        $kvstore->init($idx, $arg_params->{ $param_names->[$idx] });
+        my $name = $param_names->[$idx];
+        $kvstore->init($name, $arg_params->{ $name });
         if($update_on_kvstore)
         {
-            $kvstore->pull($idx, out => $param_on_devs, priority => -$idx);
+            $kvstore->pull($name, out => $param_on_devs, priority => -$idx);
         }
     }, $param_arrays);
 }
@@ -82,7 +84,8 @@ func _initialize_kvstore(
 func _update_params_on_kvstore(
     ArrayRef[AI::MXNet::NDArray]|ArrayRef[ArrayRef[AI::MXNet::NDArray]] $param_arrays,
     ArrayRef[AI::MXNet::NDArray]|ArrayRef[ArrayRef[AI::MXNet::NDArray]] $grad_arrays,
-    AI::MXNet::KVStore           $kvstore
+    AI::MXNet::KVStore           $kvstore,
+    ArrayRef[Str]                $param_names
 )
 {
     enumerate(sub{
@@ -91,10 +94,11 @@ func _update_params_on_kvstore(
         {
             return;
         }
+        my $name = $param_names->[$index];
         # push gradient, priority is negative index
-        $kvstore->push($index, $grad_list, priority => -$index);
+        $kvstore->push($name, $grad_list, priority => -$index);
         # pull back the weights
-        $kvstore->pull($index, out => $arg_list, priority  => -$index);
+        $kvstore->pull($name, out => $arg_list, priority  => -$index);
     }, $param_arrays, $grad_arrays);
 }
 
@@ -103,7 +107,8 @@ func _update_params(
     ArrayRef[ArrayRef[AI::MXNet::NDArray]] $grad_arrays,
     AI::MXNet::Updater                     $updater,
     Int                                    $num_device,
-    Maybe[AI::MXNet::KVStore]              $kvstore=
+    Maybe[AI::MXNet::KVStore]              $kvstore=,
+    Maybe[ArrayRef[Str]]                   $param_names=
 )
 {
     enumerate(sub{
@@ -114,16 +119,17 @@ func _update_params(
         }
         if($kvstore)
         {
+            my $name = $param_names->[$index];
             # push gradient, priority is negative index
-            $kvstore->push($index, $grad_list, priority => -$index);
+            $kvstore->push($name, $grad_list, priority => -$index);
             # pull back the sum gradients, to the same locations.
-            $kvstore->pull($index, out => $grad_list, priority => -$index);
+            $kvstore->pull($name, out => $grad_list, priority => -$index);
         }
         enumerate(sub {
             my ($k, $w, $g) = @_;
             # faked an index here, to make optimizer create diff
             # state for the same index but on diff devs, TODO(mli)
-            # use a better solution latter
+            # use a better solution later
             &{$updater}($index*$num_device+$k, $g, $w);
         }, $arg_list, $grad_list);
     }, $param_arrays, $grad_arrays);
@@ -399,7 +405,8 @@ method init_params(
     Maybe[HashRef[AI::MXNet::NDArray]] :$arg_params=,
     Maybe[HashRef[AI::MXNet::NDArray]] :$aux_params=,
     Bool                               :$allow_missing=0,
-    Bool                               :$force_init=0
+    Bool                               :$force_init=0,
+    Bool                               :$allow_extra=0
 )
 {
     if($self->params_initialized and not $force_init)
@@ -467,21 +474,23 @@ method init_params(
     $self->_p->_params_dirty(0);
 
     # copy the initialized parameters to devices
-    $self->_p->_exec_group->set_params($self->_p->_arg_params, $self->_p->_aux_params);
+    $self->_p->_exec_group->set_params($self->_p->_arg_params, $self->_p->_aux_params, $allow_extra);
 }
 
 method set_params(
     HashRef[AI::MXNet::NDArray]  $arg_params,
     HashRef[AI::MXNet::NDArray]  $aux_params,
     Bool                        :$allow_missing=0,
-    Bool                        :$force_init=1
+    Bool                        :$force_init=1,
+    Bool                        :$allow_extra=0
 )
 {
     if(not $allow_missing)
     {
         $self->init_params(
             arg_params    => $arg_params,    aux_params => $aux_params,
-            allow_missing => $allow_missing, force_init => $force_init
+            allow_missing => $allow_missing, force_init => $force_init,
+            allow_extra   => $allow_extra
         );
         return;
     }
@@ -494,7 +503,7 @@ method set_params(
         );
         return;
     }
-    $self->_p->_exec_group->set_params($arg_params, $aux_params);
+    $self->_p->_exec_group->set_params($arg_params, $aux_params, $allow_extra);
     $self->_p->_params_dirty(1);
     $self->params_initialized(1);
 }
@@ -770,6 +779,51 @@ method forward(
 )
 {
     assert($self->binded and $self->params_initialized);
+    # If starting to do the inference, force rebind the module.
+    if($self->label_shapes and not $data_batch->label)
+    {
+        confess(
+            "If you are trying to do inference, rebind module ".
+            "with 'force_rebind=True' and 'for_training=False'"
+        );
+    }
+
+    my @curr_data_shapes = map { $_->shape } @{ $self->data_shapes };
+    my @new_data_shapes  = map { $_->shape } @{ $data_batch->data };
+    if(Data::Dumper->Dump(\@curr_data_shapes) ne Data::Dumper->Dump(\@new_data_shapes))
+    {
+        my $new_dshape;
+        if($data_batch->can('provide_data') and $data_batch->provide_data)
+        {
+            $new_dshape = $data_batch->provide_data;
+        }
+        else
+        {
+            $new_dshape = [];
+            zip(sub {
+                my ($i, $shape) = @_;
+                push @{ $new_dshape }, AI::MXNet::DataDesc->new(
+                    $i->name, $shape, $i->dtype, $i->layout
+                );
+            }, $self->data_shapes, \@new_data_shapes);
+        }
+        my $new_lshape;
+        if($data_batch->can('provide_label') and $data_batch->provide_label)
+        {
+            $new_lshape = $data_batch->provide_label;
+        }
+        elsif($data_batch->can('label') and $data_batch->label)
+        {
+            $new_lshape = [];
+            zip(sub {
+                my ($i, $j) = @_;
+                push @{ $new_lshape }, AI::MXNet::DataDesc->new(
+                    $i->name, $j->shape, $i->dtype, $i->layout
+                );
+            }, $self->label_shapes, $data_batch->label);
+        }
+        $self->reshape(data_shapes => $new_dshape, label_shapes => $new_lshape);
+    }
     $self->_p->_exec_group->forward($data_batch, $is_train);
 }
 
@@ -788,7 +842,8 @@ method update()
         _update_params_on_kvstore(
             $self->_p->_exec_group->_p->param_arrays,
             $self->_p->_exec_group->_p->grad_arrays,
-            $self->_p->_kvstore
+            $self->_p->_kvstore,
+            $self->_p->_exec_group->param_names
         );
     }
     else
@@ -798,7 +853,8 @@ method update()
             $self->_p->_exec_group->_p->grad_arrays,
             $self->_p->_updater,
             scalar(@{ $self->_p->_context}),
-            $self->_p->_kvstore
+            $self->_p->_kvstore,
+            $self->_p->_exec_group->param_names
         );
     }
 }
